// WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.1

#include "py.Windows.System.Profile.SystemManufacturers.h"

namespace py::cpp::Windows::System::Profile::SystemManufacturers
{
    // ----- OemSupportInfo class --------------------

    static PyObject* _new_OemSupportInfo(PyTypeObject* /*unused*/, PyObject* /*unused*/, PyObject* /*unused*/) noexcept
    {
        static_assert(py::py_type<winrt::Windows::System::Profile::SystemManufacturers::OemSupportInfo>::type_name);
        py::set_invalid_activation_error(py::py_type<winrt::Windows::System::Profile::SystemManufacturers::OemSupportInfo>::type_name);
        return nullptr;
    }

    static void _dealloc_OemSupportInfo(py::wrapper::Windows::System::Profile::SystemManufacturers::OemSupportInfo* self) noexcept
    {
        auto tp = Py_TYPE(self);
        std::destroy_at(&self->obj);
        tp->tp_free(self);
        Py_DECREF(tp);
    }

    static PyObject* OemSupportInfo_get_SupportAppLink(py::wrapper::Windows::System::Profile::SystemManufacturers::OemSupportInfo* self, void* /*unused*/) noexcept
    {
        try
        {
            static std::optional<bool> is_property_present{};

            if (!is_property_present.has_value())
            {
                is_property_present = winrt::Windows::Foundation::Metadata::ApiInformation::IsPropertyPresent(L"Windows.System.Profile.SystemManufacturers.OemSupportInfo", L"SupportAppLink");
            }

            if (!is_property_present.value())
            {
                PyErr_SetString(PyExc_AttributeError, "property is not available in this version of Windows");
                return nullptr;
            }

            return py::convert([&]()
            {
                auto _gil = release_gil();
                return self->obj.SupportAppLink();
            }());
        }
        catch (...)
        {
            py::to_PyErr();
            return nullptr;
        }
    }

    static PyObject* OemSupportInfo_get_SupportLink(py::wrapper::Windows::System::Profile::SystemManufacturers::OemSupportInfo* self, void* /*unused*/) noexcept
    {
        try
        {
            static std::optional<bool> is_property_present{};

            if (!is_property_present.has_value())
            {
                is_property_present = winrt::Windows::Foundation::Metadata::ApiInformation::IsPropertyPresent(L"Windows.System.Profile.SystemManufacturers.OemSupportInfo", L"SupportLink");
            }

            if (!is_property_present.value())
            {
                PyErr_SetString(PyExc_AttributeError, "property is not available in this version of Windows");
                return nullptr;
            }

            return py::convert([&]()
            {
                auto _gil = release_gil();
                return self->obj.SupportLink();
            }());
        }
        catch (...)
        {
            py::to_PyErr();
            return nullptr;
        }
    }

    static PyObject* OemSupportInfo_get_SupportProvider(py::wrapper::Windows::System::Profile::SystemManufacturers::OemSupportInfo* self, void* /*unused*/) noexcept
    {
        try
        {
            static std::optional<bool> is_property_present{};

            if (!is_property_present.has_value())
            {
                is_property_present = winrt::Windows::Foundation::Metadata::ApiInformation::IsPropertyPresent(L"Windows.System.Profile.SystemManufacturers.OemSupportInfo", L"SupportProvider");
            }

            if (!is_property_present.value())
            {
                PyErr_SetString(PyExc_AttributeError, "property is not available in this version of Windows");
                return nullptr;
            }

            return py::convert([&]()
            {
                auto _gil = release_gil();
                return self->obj.SupportProvider();
            }());
        }
        catch (...)
        {
            py::to_PyErr();
            return nullptr;
        }
    }

    static PyObject* _assign_array_OemSupportInfo(PyObject* /*unused*/, PyObject* arg) noexcept
    {
        auto array = std::make_unique<py::ComArray<winrt::Windows::System::Profile::SystemManufacturers::OemSupportInfo>>();
        if (!py::cpp::_winrt::Array_Assign(arg, std::move(array)))
        {
            return nullptr;
        }
        Py_RETURN_NONE;
    }

    static PyObject* _from_OemSupportInfo(PyObject* /*unused*/, PyObject* arg) noexcept
    {
        try
        {
            auto return_value = py::convert_to<winrt::Windows::Foundation::IInspectable>(arg);
            return py::convert(return_value.as<winrt::Windows::System::Profile::SystemManufacturers::OemSupportInfo>());
        }
        catch (...)
        {
            py::to_PyErr();
            return nullptr;
        }
    }

    static PyMethodDef _methods_OemSupportInfo[] = {
        { "_assign_array_", _assign_array_OemSupportInfo, METH_O | METH_STATIC, nullptr },
        { "_from", reinterpret_cast<PyCFunction>(_from_OemSupportInfo), METH_O | METH_STATIC, nullptr },
        { }};

    static PyGetSetDef _getset_OemSupportInfo[] = {
        { "support_app_link", reinterpret_cast<getter>(OemSupportInfo_get_SupportAppLink), nullptr, nullptr, nullptr },
        { "support_link", reinterpret_cast<getter>(OemSupportInfo_get_SupportLink), nullptr, nullptr, nullptr },
        { "support_provider", reinterpret_cast<getter>(OemSupportInfo_get_SupportProvider), nullptr, nullptr, nullptr },
        { }};

    static PyType_Slot _type_slots_OemSupportInfo[] = {
        { Py_tp_new, reinterpret_cast<void*>(_new_OemSupportInfo) },
        { Py_tp_dealloc, reinterpret_cast<void*>(_dealloc_OemSupportInfo) },
        { Py_tp_methods, reinterpret_cast<void*>(_methods_OemSupportInfo) },
        { Py_tp_getset, reinterpret_cast<void*>(_getset_OemSupportInfo) },
        { }};

    static PyType_Spec type_spec_OemSupportInfo = {
        "winrt._winrt_windows_system_profile_systemmanufacturers.OemSupportInfo",
        sizeof(py::wrapper::Windows::System::Profile::SystemManufacturers::OemSupportInfo),
        0,
        Py_TPFLAGS_DEFAULT,
        _type_slots_OemSupportInfo};

    // ----- SmbiosInformation class --------------------

    static PyObject* _new_SmbiosInformation(PyTypeObject* /*unused*/, PyObject* /*unused*/, PyObject* /*unused*/) noexcept
    {
        static_assert(py::py_type<winrt::Windows::System::Profile::SystemManufacturers::SmbiosInformation>::type_name);
        py::set_invalid_activation_error(py::py_type<winrt::Windows::System::Profile::SystemManufacturers::SmbiosInformation>::type_name);
        return nullptr;
    }

    static PyObject* SmbiosInformation_get_SerialNumber(PyObject* /*unused*/, void* /*unused*/) noexcept
    {
        try
        {
            static std::optional<bool> is_property_present{};

            if (!is_property_present.has_value())
            {
                is_property_present = winrt::Windows::Foundation::Metadata::ApiInformation::IsPropertyPresent(L"Windows.System.Profile.SystemManufacturers.SmbiosInformation", L"SerialNumber");
            }

            if (!is_property_present.value())
            {
                PyErr_SetString(PyExc_AttributeError, "property is not available in this version of Windows");
                return nullptr;
            }

            return py::convert([&]()
            {
                auto _gil = release_gil();
                return winrt::Windows::System::Profile::SystemManufacturers::SmbiosInformation::SerialNumber();
            }());
        }
        catch (...)
        {
            py::to_PyErr();
            return nullptr;
        }
    }

    static PyMethodDef _methods_SmbiosInformation[] = {
        { }};

    static PyGetSetDef _getset_SmbiosInformation[] = {
        { }};

    static PyType_Slot _type_slots_SmbiosInformation[] = {
        { Py_tp_new, reinterpret_cast<void*>(_new_SmbiosInformation) },
        { Py_tp_methods, reinterpret_cast<void*>(_methods_SmbiosInformation) },
        { Py_tp_getset, reinterpret_cast<void*>(_getset_SmbiosInformation) },
        { }};

    static PyType_Spec type_spec_SmbiosInformation = {
        "winrt._winrt_windows_system_profile_systemmanufacturers.SmbiosInformation",
        0,
        0,
        Py_TPFLAGS_DEFAULT,
        _type_slots_SmbiosInformation};

    static PyGetSetDef getset_SmbiosInformation_Static[] = {
        { "serial_number", reinterpret_cast<getter>(SmbiosInformation_get_SerialNumber), nullptr, nullptr, nullptr },
        { }};

    static PyMethodDef methods_SmbiosInformation_Static[] = {
        { }};

    static PyType_Slot type_slots_SmbiosInformation_Static[] = 
    {
        { Py_tp_base, reinterpret_cast<void*>(&PyType_Type) },
        { Py_tp_getset, reinterpret_cast<void*>(getset_SmbiosInformation_Static) },
        { Py_tp_methods, reinterpret_cast<void*>(methods_SmbiosInformation_Static) },
        { }
    };

    static PyType_Spec type_spec_SmbiosInformation_Static = {
        "winrt._winrt_windows_system_profile_systemmanufacturers.SmbiosInformation_Static",
        static_cast<int>(PyType_Type.tp_basicsize),
        static_cast<int>(PyType_Type.tp_itemsize),
        Py_TPFLAGS_DEFAULT,
        type_slots_SmbiosInformation_Static};

    // ----- SystemSupportDeviceInfo class --------------------

    static PyObject* _new_SystemSupportDeviceInfo(PyTypeObject* /*unused*/, PyObject* /*unused*/, PyObject* /*unused*/) noexcept
    {
        static_assert(py::py_type<winrt::Windows::System::Profile::SystemManufacturers::SystemSupportDeviceInfo>::type_name);
        py::set_invalid_activation_error(py::py_type<winrt::Windows::System::Profile::SystemManufacturers::SystemSupportDeviceInfo>::type_name);
        return nullptr;
    }

    static void _dealloc_SystemSupportDeviceInfo(py::wrapper::Windows::System::Profile::SystemManufacturers::SystemSupportDeviceInfo* self) noexcept
    {
        auto tp = Py_TYPE(self);
        std::destroy_at(&self->obj);
        tp->tp_free(self);
        Py_DECREF(tp);
    }

    static PyObject* SystemSupportDeviceInfo_get_FriendlyName(py::wrapper::Windows::System::Profile::SystemManufacturers::SystemSupportDeviceInfo* self, void* /*unused*/) noexcept
    {
        try
        {
            static std::optional<bool> is_property_present{};

            if (!is_property_present.has_value())
            {
                is_property_present = winrt::Windows::Foundation::Metadata::ApiInformation::IsPropertyPresent(L"Windows.System.Profile.SystemManufacturers.SystemSupportDeviceInfo", L"FriendlyName");
            }

            if (!is_property_present.value())
            {
                PyErr_SetString(PyExc_AttributeError, "property is not available in this version of Windows");
                return nullptr;
            }

            return py::convert([&]()
            {
                auto _gil = release_gil();
                return self->obj.FriendlyName();
            }());
        }
        catch (...)
        {
            py::to_PyErr();
            return nullptr;
        }
    }

    static PyObject* SystemSupportDeviceInfo_get_OperatingSystem(py::wrapper::Windows::System::Profile::SystemManufacturers::SystemSupportDeviceInfo* self, void* /*unused*/) noexcept
    {
        try
        {
            static std::optional<bool> is_property_present{};

            if (!is_property_present.has_value())
            {
                is_property_present = winrt::Windows::Foundation::Metadata::ApiInformation::IsPropertyPresent(L"Windows.System.Profile.SystemManufacturers.SystemSupportDeviceInfo", L"OperatingSystem");
            }

            if (!is_property_present.value())
            {
                PyErr_SetString(PyExc_AttributeError, "property is not available in this version of Windows");
                return nullptr;
            }

            return py::convert([&]()
            {
                auto _gil = release_gil();
                return self->obj.OperatingSystem();
            }());
        }
        catch (...)
        {
            py::to_PyErr();
            return nullptr;
        }
    }

    static PyObject* SystemSupportDeviceInfo_get_SystemFirmwareVersion(py::wrapper::Windows::System::Profile::SystemManufacturers::SystemSupportDeviceInfo* self, void* /*unused*/) noexcept
    {
        try
        {
            static std::optional<bool> is_property_present{};

            if (!is_property_present.has_value())
            {
                is_property_present = winrt::Windows::Foundation::Metadata::ApiInformation::IsPropertyPresent(L"Windows.System.Profile.SystemManufacturers.SystemSupportDeviceInfo", L"SystemFirmwareVersion");
            }

            if (!is_property_present.value())
            {
                PyErr_SetString(PyExc_AttributeError, "property is not available in this version of Windows");
                return nullptr;
            }

            return py::convert([&]()
            {
                auto _gil = release_gil();
                return self->obj.SystemFirmwareVersion();
            }());
        }
        catch (...)
        {
            py::to_PyErr();
            return nullptr;
        }
    }

    static PyObject* SystemSupportDeviceInfo_get_SystemHardwareVersion(py::wrapper::Windows::System::Profile::SystemManufacturers::SystemSupportDeviceInfo* self, void* /*unused*/) noexcept
    {
        try
        {
            static std::optional<bool> is_property_present{};

            if (!is_property_present.has_value())
            {
                is_property_present = winrt::Windows::Foundation::Metadata::ApiInformation::IsPropertyPresent(L"Windows.System.Profile.SystemManufacturers.SystemSupportDeviceInfo", L"SystemHardwareVersion");
            }

            if (!is_property_present.value())
            {
                PyErr_SetString(PyExc_AttributeError, "property is not available in this version of Windows");
                return nullptr;
            }

            return py::convert([&]()
            {
                auto _gil = release_gil();
                return self->obj.SystemHardwareVersion();
            }());
        }
        catch (...)
        {
            py::to_PyErr();
            return nullptr;
        }
    }

    static PyObject* SystemSupportDeviceInfo_get_SystemManufacturer(py::wrapper::Windows::System::Profile::SystemManufacturers::SystemSupportDeviceInfo* self, void* /*unused*/) noexcept
    {
        try
        {
            static std::optional<bool> is_property_present{};

            if (!is_property_present.has_value())
            {
                is_property_present = winrt::Windows::Foundation::Metadata::ApiInformation::IsPropertyPresent(L"Windows.System.Profile.SystemManufacturers.SystemSupportDeviceInfo", L"SystemManufacturer");
            }

            if (!is_property_present.value())
            {
                PyErr_SetString(PyExc_AttributeError, "property is not available in this version of Windows");
                return nullptr;
            }

            return py::convert([&]()
            {
                auto _gil = release_gil();
                return self->obj.SystemManufacturer();
            }());
        }
        catch (...)
        {
            py::to_PyErr();
            return nullptr;
        }
    }

    static PyObject* SystemSupportDeviceInfo_get_SystemProductName(py::wrapper::Windows::System::Profile::SystemManufacturers::SystemSupportDeviceInfo* self, void* /*unused*/) noexcept
    {
        try
        {
            static std::optional<bool> is_property_present{};

            if (!is_property_present.has_value())
            {
                is_property_present = winrt::Windows::Foundation::Metadata::ApiInformation::IsPropertyPresent(L"Windows.System.Profile.SystemManufacturers.SystemSupportDeviceInfo", L"SystemProductName");
            }

            if (!is_property_present.value())
            {
                PyErr_SetString(PyExc_AttributeError, "property is not available in this version of Windows");
                return nullptr;
            }

            return py::convert([&]()
            {
                auto _gil = release_gil();
                return self->obj.SystemProductName();
            }());
        }
        catch (...)
        {
            py::to_PyErr();
            return nullptr;
        }
    }

    static PyObject* SystemSupportDeviceInfo_get_SystemSku(py::wrapper::Windows::System::Profile::SystemManufacturers::SystemSupportDeviceInfo* self, void* /*unused*/) noexcept
    {
        try
        {
            static std::optional<bool> is_property_present{};

            if (!is_property_present.has_value())
            {
                is_property_present = winrt::Windows::Foundation::Metadata::ApiInformation::IsPropertyPresent(L"Windows.System.Profile.SystemManufacturers.SystemSupportDeviceInfo", L"SystemSku");
            }

            if (!is_property_present.value())
            {
                PyErr_SetString(PyExc_AttributeError, "property is not available in this version of Windows");
                return nullptr;
            }

            return py::convert([&]()
            {
                auto _gil = release_gil();
                return self->obj.SystemSku();
            }());
        }
        catch (...)
        {
            py::to_PyErr();
            return nullptr;
        }
    }

    static PyObject* _assign_array_SystemSupportDeviceInfo(PyObject* /*unused*/, PyObject* arg) noexcept
    {
        auto array = std::make_unique<py::ComArray<winrt::Windows::System::Profile::SystemManufacturers::SystemSupportDeviceInfo>>();
        if (!py::cpp::_winrt::Array_Assign(arg, std::move(array)))
        {
            return nullptr;
        }
        Py_RETURN_NONE;
    }

    static PyObject* _from_SystemSupportDeviceInfo(PyObject* /*unused*/, PyObject* arg) noexcept
    {
        try
        {
            auto return_value = py::convert_to<winrt::Windows::Foundation::IInspectable>(arg);
            return py::convert(return_value.as<winrt::Windows::System::Profile::SystemManufacturers::SystemSupportDeviceInfo>());
        }
        catch (...)
        {
            py::to_PyErr();
            return nullptr;
        }
    }

    static PyMethodDef _methods_SystemSupportDeviceInfo[] = {
        { "_assign_array_", _assign_array_SystemSupportDeviceInfo, METH_O | METH_STATIC, nullptr },
        { "_from", reinterpret_cast<PyCFunction>(_from_SystemSupportDeviceInfo), METH_O | METH_STATIC, nullptr },
        { }};

    static PyGetSetDef _getset_SystemSupportDeviceInfo[] = {
        { "friendly_name", reinterpret_cast<getter>(SystemSupportDeviceInfo_get_FriendlyName), nullptr, nullptr, nullptr },
        { "operating_system", reinterpret_cast<getter>(SystemSupportDeviceInfo_get_OperatingSystem), nullptr, nullptr, nullptr },
        { "system_firmware_version", reinterpret_cast<getter>(SystemSupportDeviceInfo_get_SystemFirmwareVersion), nullptr, nullptr, nullptr },
        { "system_hardware_version", reinterpret_cast<getter>(SystemSupportDeviceInfo_get_SystemHardwareVersion), nullptr, nullptr, nullptr },
        { "system_manufacturer", reinterpret_cast<getter>(SystemSupportDeviceInfo_get_SystemManufacturer), nullptr, nullptr, nullptr },
        { "system_product_name", reinterpret_cast<getter>(SystemSupportDeviceInfo_get_SystemProductName), nullptr, nullptr, nullptr },
        { "system_sku", reinterpret_cast<getter>(SystemSupportDeviceInfo_get_SystemSku), nullptr, nullptr, nullptr },
        { }};

    static PyType_Slot _type_slots_SystemSupportDeviceInfo[] = {
        { Py_tp_new, reinterpret_cast<void*>(_new_SystemSupportDeviceInfo) },
        { Py_tp_dealloc, reinterpret_cast<void*>(_dealloc_SystemSupportDeviceInfo) },
        { Py_tp_methods, reinterpret_cast<void*>(_methods_SystemSupportDeviceInfo) },
        { Py_tp_getset, reinterpret_cast<void*>(_getset_SystemSupportDeviceInfo) },
        { }};

    static PyType_Spec type_spec_SystemSupportDeviceInfo = {
        "winrt._winrt_windows_system_profile_systemmanufacturers.SystemSupportDeviceInfo",
        sizeof(py::wrapper::Windows::System::Profile::SystemManufacturers::SystemSupportDeviceInfo),
        0,
        Py_TPFLAGS_DEFAULT,
        _type_slots_SystemSupportDeviceInfo};

    // ----- SystemSupportInfo class --------------------

    static PyObject* _new_SystemSupportInfo(PyTypeObject* /*unused*/, PyObject* /*unused*/, PyObject* /*unused*/) noexcept
    {
        static_assert(py::py_type<winrt::Windows::System::Profile::SystemManufacturers::SystemSupportInfo>::type_name);
        py::set_invalid_activation_error(py::py_type<winrt::Windows::System::Profile::SystemManufacturers::SystemSupportInfo>::type_name);
        return nullptr;
    }

    static PyObject* SystemSupportInfo_get_LocalSystemEdition(PyObject* /*unused*/, void* /*unused*/) noexcept
    {
        try
        {
            static std::optional<bool> is_property_present{};

            if (!is_property_present.has_value())
            {
                is_property_present = winrt::Windows::Foundation::Metadata::ApiInformation::IsPropertyPresent(L"Windows.System.Profile.SystemManufacturers.SystemSupportInfo", L"LocalSystemEdition");
            }

            if (!is_property_present.value())
            {
                PyErr_SetString(PyExc_AttributeError, "property is not available in this version of Windows");
                return nullptr;
            }

            return py::convert([&]()
            {
                auto _gil = release_gil();
                return winrt::Windows::System::Profile::SystemManufacturers::SystemSupportInfo::LocalSystemEdition();
            }());
        }
        catch (...)
        {
            py::to_PyErr();
            return nullptr;
        }
    }

    static PyObject* SystemSupportInfo_get_OemSupportInfo(PyObject* /*unused*/, void* /*unused*/) noexcept
    {
        try
        {
            static std::optional<bool> is_property_present{};

            if (!is_property_present.has_value())
            {
                is_property_present = winrt::Windows::Foundation::Metadata::ApiInformation::IsPropertyPresent(L"Windows.System.Profile.SystemManufacturers.SystemSupportInfo", L"OemSupportInfo");
            }

            if (!is_property_present.value())
            {
                PyErr_SetString(PyExc_AttributeError, "property is not available in this version of Windows");
                return nullptr;
            }

            return py::convert([&]()
            {
                auto _gil = release_gil();
                return winrt::Windows::System::Profile::SystemManufacturers::SystemSupportInfo::OemSupportInfo();
            }());
        }
        catch (...)
        {
            py::to_PyErr();
            return nullptr;
        }
    }

    static PyObject* SystemSupportInfo_get_LocalDeviceInfo(PyObject* /*unused*/, void* /*unused*/) noexcept
    {
        try
        {
            static std::optional<bool> is_property_present{};

            if (!is_property_present.has_value())
            {
                is_property_present = winrt::Windows::Foundation::Metadata::ApiInformation::IsPropertyPresent(L"Windows.System.Profile.SystemManufacturers.SystemSupportInfo", L"LocalDeviceInfo");
            }

            if (!is_property_present.value())
            {
                PyErr_SetString(PyExc_AttributeError, "property is not available in this version of Windows");
                return nullptr;
            }

            return py::convert([&]()
            {
                auto _gil = release_gil();
                return winrt::Windows::System::Profile::SystemManufacturers::SystemSupportInfo::LocalDeviceInfo();
            }());
        }
        catch (...)
        {
            py::to_PyErr();
            return nullptr;
        }
    }

    static PyMethodDef _methods_SystemSupportInfo[] = {
        { }};

    static PyGetSetDef _getset_SystemSupportInfo[] = {
        { }};

    static PyType_Slot _type_slots_SystemSupportInfo[] = {
        { Py_tp_new, reinterpret_cast<void*>(_new_SystemSupportInfo) },
        { Py_tp_methods, reinterpret_cast<void*>(_methods_SystemSupportInfo) },
        { Py_tp_getset, reinterpret_cast<void*>(_getset_SystemSupportInfo) },
        { }};

    static PyType_Spec type_spec_SystemSupportInfo = {
        "winrt._winrt_windows_system_profile_systemmanufacturers.SystemSupportInfo",
        0,
        0,
        Py_TPFLAGS_DEFAULT,
        _type_slots_SystemSupportInfo};

    static PyGetSetDef getset_SystemSupportInfo_Static[] = {
        { "local_system_edition", reinterpret_cast<getter>(SystemSupportInfo_get_LocalSystemEdition), nullptr, nullptr, nullptr },
        { "oem_support_info", reinterpret_cast<getter>(SystemSupportInfo_get_OemSupportInfo), nullptr, nullptr, nullptr },
        { "local_device_info", reinterpret_cast<getter>(SystemSupportInfo_get_LocalDeviceInfo), nullptr, nullptr, nullptr },
        { }};

    static PyMethodDef methods_SystemSupportInfo_Static[] = {
        { }};

    static PyType_Slot type_slots_SystemSupportInfo_Static[] = 
    {
        { Py_tp_base, reinterpret_cast<void*>(&PyType_Type) },
        { Py_tp_getset, reinterpret_cast<void*>(getset_SystemSupportInfo_Static) },
        { Py_tp_methods, reinterpret_cast<void*>(methods_SystemSupportInfo_Static) },
        { }
    };

    static PyType_Spec type_spec_SystemSupportInfo_Static = {
        "winrt._winrt_windows_system_profile_systemmanufacturers.SystemSupportInfo_Static",
        static_cast<int>(PyType_Type.tp_basicsize),
        static_cast<int>(PyType_Type.tp_itemsize),
        Py_TPFLAGS_DEFAULT,
        type_slots_SystemSupportInfo_Static};

    // ----- Windows.System.Profile.SystemManufacturers Initialization --------------------

    PyDoc_STRVAR(module_doc, "Windows.System.Profile.SystemManufacturers");

    static PyModuleDef module_def = {
        PyModuleDef_HEAD_INIT,
        "_winrt_windows_system_profile_systemmanufacturers",
        module_doc,
        0,
        nullptr,
        nullptr,
        nullptr,
        nullptr,
        nullptr};
} // py::cpp::Windows::System::Profile::SystemManufacturers

PyMODINIT_FUNC PyInit__winrt_windows_system_profile_systemmanufacturers(void) noexcept
{
    using namespace py::cpp::Windows::System::Profile::SystemManufacturers;

    if (py::import_winrt_runtime() == -1)
    {
        return nullptr;
    }

    py::pyobj_handle module{PyModule_Create(&module_def)};

    if (!module)
    {
        return nullptr;
    }

    auto inspectable_meta_type = py::get_inspectable_meta_type();
    if (!inspectable_meta_type)
    {
        return nullptr;
    }

    auto object_type = py::get_object_type();
    if (!object_type)
    {
        return nullptr;
    }

    py::pyobj_handle object_bases{PyTuple_Pack(1, object_type)};

    if (!object_bases)
    {
        return nullptr;
    }

    py::pytype_handle OemSupportInfo_type{py::register_python_type(module.get(), &type_spec_OemSupportInfo, object_bases.get(), inspectable_meta_type)};
    if (!OemSupportInfo_type)
    {
        return nullptr;
    }

    py::pyobj_handle SmbiosInformation_Static_bases{PyTuple_Pack(1, reinterpret_cast<PyObject*>(inspectable_meta_type))};
    if (!SmbiosInformation_Static_bases)
    {
        return nullptr;
    }

    py::pyobj_handle type_SmbiosInformation_Static{PyType_FromSpecWithBases(&type_spec_SmbiosInformation_Static, SmbiosInformation_Static_bases.get())};
    if (!type_SmbiosInformation_Static)
    {
        return nullptr;
    }

    py::pytype_handle SmbiosInformation_type{py::register_python_type(module.get(), &type_spec_SmbiosInformation, object_bases.get(), reinterpret_cast<PyTypeObject*>(type_SmbiosInformation_Static.get()))};
    if (!SmbiosInformation_type)
    {
        return nullptr;
    }

    py::pytype_handle SystemSupportDeviceInfo_type{py::register_python_type(module.get(), &type_spec_SystemSupportDeviceInfo, object_bases.get(), inspectable_meta_type)};
    if (!SystemSupportDeviceInfo_type)
    {
        return nullptr;
    }

    py::pyobj_handle SystemSupportInfo_Static_bases{PyTuple_Pack(1, reinterpret_cast<PyObject*>(inspectable_meta_type))};
    if (!SystemSupportInfo_Static_bases)
    {
        return nullptr;
    }

    py::pyobj_handle type_SystemSupportInfo_Static{PyType_FromSpecWithBases(&type_spec_SystemSupportInfo_Static, SystemSupportInfo_Static_bases.get())};
    if (!type_SystemSupportInfo_Static)
    {
        return nullptr;
    }

    py::pytype_handle SystemSupportInfo_type{py::register_python_type(module.get(), &type_spec_SystemSupportInfo, object_bases.get(), reinterpret_cast<PyTypeObject*>(type_SystemSupportInfo_Static.get()))};
    if (!SystemSupportInfo_type)
    {
        return nullptr;
    }


    return module.detach();
}
